@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.1 2002/03/25 12:54:59 murrayc Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.1.1.1 2003/01/21 13:41:28 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -24,7 +24,7 @@ int main(int argc, char *argv[])
   Gtk::Main kit(argc, argv);
 
   RadioButtons buttons;
-  kit.run(buttons); //Shows the window and returns when it is closed.
+  Gtk::Main::run(buttons); //Shows the window and returns when it is closed.
 
   return 0;
 }
