@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.3 2006/07/10 03:15:27 jjongsma Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.4 2006/07/19 02:55:20 jjongsma Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -16,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include <gtkmm/main.h>
+#include <gtkmm.h>
 #include "examplewindow.h"
 
 int main(int argc, char *argv[])
